import "./ToastStyling.scss";
import * as React from "react";
/**
 * View Message of the Toast Notification
 */
export declare type IToastLink = {
    /**
     *  Either the URL to be novaigated to, or the callback to be executed when clicking the <a> tag.
     */
    url: (() => void) | string;
    /**
     * Text of the <a> tag
     */
    title: string;
};
/**
 *  Toast Property Interface
 */
export declare type IToastProps = {
    /**
     * Text of the Notification Message
     */
    text: string;
    /**
     * Category of the Toast, which controls the border color, as well as the category icon.
     */
    category: "informational" | "error" | "success";
    /**
     * The Type of the Toast.
     * Persisting Toasts will not be closed automatically, and will contain a close button.
     * Temporary Toasts will automatically close after 7 seconds and will not contain a close button.
     */
    type: "persisting" | "temporary";
    /**
     * Boolean indicating when the toast is visible.
     * When false, will close the Toast and call onRemove when finished closing.
     */
    isVisible: boolean;
    /**
     * Duration of the toast.
     * By default, the toast will close after 7 seconds.
     */
    duration?: number;
    /**
     * Boolean indicating when the close button is visible.
     * When false, the toast will not have any close button.
     */
    hasCloseButton?: boolean;
    /**
     * A URL or Callback that can be used to add additional information to a Toast
     */
    link?: IToastLink;
    /**
     * Function called when the toast is all the way closed.
     */
    onRemove?: () => void;
};
/**
 * Toast Property States
 */
declare type IToastState = {
    isVisible: boolean;
    height: number;
};
/**
 * Generic Toast Notification Component
 * +++++
 * <Toast type="persisting" text="Job processing completed." category="success" link={{url:() => {alert("Link callback")}, title:"View the report"}} />
 * <Toast type="temporary" text="Processing completed." category="success" />
 * <Toast type="persisting" text="Bacon ipsum dolor amet shoulder andouille meatball meatloaf chicken pork loin alcatra boudin pig beef ribs. Short loin short ribs buffalo shankle, jerky fatback leberkas meatball boudin. Kevin meatloaf flank pancetta, picanha tail kielbasa salami ham hock sirloin cow frankfurter capicola. Jowl shankle short ribs rump shank ribeye, frankfurter sausage." category="informational" link={{url:"http://ux.bentley.com/bwc/react/", title:"View"}} />
 * <Toast type="temporary" text="26 files are available for synchonization." category="informational" />
 * <Toast type="persisting" text="Job processing error." category="error" />
 */
export declare class Toast extends React.Component<IToastProps, IToastState> {
    private closeTimeout;
    constructor(props: IToastProps);
    render(): JSX.Element;
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(prevProps: IToastProps): void;
    /**
     * Close the Toast Notification
     */
    private close;
    /**
     * Category Management Function for proper Notification Icon
     * Return the Status Icon according to the category prop
     */
    private getCategoryIcon;
    /**
     * Set the Timer to close the Toast Notification after 7 seconds
     */
    private setCloseTimeout;
    /**
     * Remove the Timer to close the Toast Notification (if its exists)
     */
    private clearCloseTimeout;
    private onRef;
}
export default Toast;
